@@ -124,7 +124,7 @@ def main():
             os.environ["NUITKA_PTH_IMPORTED"] = repr(detectPthImportedPackages())
 
         os.environ["NUITKA_SITE_FLAG"] = (
-            str(sys.flags.no_site) if "no_site" not in Options.getPythonFlags() else "1"
+            str(sys.flags.no_site) if not Options.hasPythonFlagNoSite() else "1"
         )
 
         os.environ["PYTHONHASHSEED"] = "0"
